# py2pyd

**py2pyd** is a tool to compile Python scripts (`.py`) into `.pyd` files using Cython.

## Installation

Run:
```shell
pip install py2pyd

#Usage:

To compile a Python file to a PYD DLL:

```shell
py2pyd myscript.py

#License
MIT License

